import React, { Suspense } from 'react';
import { observer } from 'mobx-react';
// locals
import { HorizontalResizeHandle, VerticalResizeHandle } from './ResizeHandles';
import TreeRuler from './tree/TreeRuler';
import Header from './header/Header';
import MSAPanel from './msa/MSAPanel';
import TreePanel from './tree/TreePanel';
import Minimap from './minimap/Minimap';
function TopArea({ model }) {
    return (React.createElement("div", { style: { display: 'flex' } },
        React.createElement(TreeRuler, { model: model }),
        React.createElement(Minimap, { model: model })));
}
function MainArea({ model }) {
    return (React.createElement("div", { style: { display: 'flex' } },
        React.createElement(TreePanel, { model: model }),
        React.createElement(VerticalResizeHandle, { model: model }),
        React.createElement(MSAPanel, { model: model })));
}
const View = observer(function ({ model }) {
    return (React.createElement("div", { style: { position: 'relative' } },
        React.createElement(TopArea, { model: model }),
        React.createElement(MainArea, { model: model })));
});
const MSAView = observer(function ({ model }) {
    const { height, DialogComponent, DialogProps } = model;
    return (React.createElement("div", null,
        React.createElement("div", { style: { height, overflow: 'hidden' } },
            React.createElement(Header, { model: model }),
            React.createElement(View, { model: model })),
        React.createElement(HorizontalResizeHandle, { model: model }),
        DialogComponent ? (React.createElement(Suspense, { fallback: null },
            React.createElement(DialogComponent, { ...DialogProps }))) : null));
});
export default MSAView;
//# sourceMappingURL=MSAView.js.map