import React, { useState } from 'react';
import { DialogContent, DialogActions, Button, TextField, MenuItem, Typography, } from '@mui/material';
import { Dialog, FileSelector } from '@jbrowse/core/ui';
import { observer } from 'mobx-react';
export default observer(function ({ model, onClose, open, }) {
    const options = model.rows.map(r => r[0]);
    const [trackFile, setTrackFile] = useState();
    const [currentOption, setCurrentOption] = useState('');
    return (React.createElement(Dialog, { onClose: () => onClose(), open: open, title: "Add track" },
        React.createElement(DialogContent, null,
            React.createElement(Typography, null, "Open relevant per-alignment tracks e.g. protein domains"),
            React.createElement(TextField, { select: true, helperText: "Which row does this track apply to?", value: currentOption, onChange: event => {
                    setCurrentOption(event.target.value);
                } }, options.map((option, index) => (React.createElement(MenuItem, { key: `${option}-${index}`, value: option }, option)))),
            React.createElement(FileSelector, { location: trackFile, setLocation: setTrackFile }),
            React.createElement(DialogActions, null,
                React.createElement(Button, { onClick: () => {
                        model.setError(undefined);
                        if (trackFile) {
                            model.setMSAFilehandle(trackFile);
                        }
                    }, variant: "contained", color: "primary" }, "Open"),
                React.createElement(Button, { color: "secondary", variant: "contained", onClick: () => onClose() }, "Cancel")))));
});
//# sourceMappingURL=AddTrackDialog.js.map