import React, { useState } from 'react';
import { Dialog, ErrorMessage } from '@jbrowse/core/ui';
import { Button, DialogContent, DialogActions, FormControlLabel, FormControl, FormLabel, RadioGroup, Radio, Typography, useTheme, } from '@mui/material';
import Checkbox2 from '../Checkbox2';
export default function ExportSVGDialog({ model, onClose, }) {
    const [includeMinimap, setIncludeMinimap] = useState(true);
    const [exportType, setExportType] = useState('viewport');
    const [error, setError] = useState();
    const theme = useTheme();
    return (React.createElement(Dialog, { onClose: () => onClose(), open: true, title: "Export SVG" },
        React.createElement(DialogContent, null,
            error ? React.createElement(ErrorMessage, { error: error }) : null,
            React.createElement(Typography, null, "Settings:"),
            React.createElement(Checkbox2, { label: "Include minimap?", disabled: exportType === 'entire', checked: includeMinimap, onChange: () => setIncludeMinimap(!includeMinimap) }),
            React.createElement("div", null,
                React.createElement(FormControl, null,
                    React.createElement(FormLabel, null, "Export type"),
                    React.createElement(RadioGroup, { value: exportType, onChange: event => setExportType(event.target.value) },
                        React.createElement(FormControlLabel, { value: "entire", control: React.createElement(Radio, null), label: "Entire MSA" }),
                        React.createElement(FormControlLabel, { value: "viewport", control: React.createElement(Radio, null), label: "Current viewport only" }))))),
        React.createElement(DialogActions, null,
            React.createElement(Button, { variant: "contained", color: "primary", onClick: async () => {
                    try {
                        await model.exportSVG({
                            theme,
                            includeMinimap: exportType === 'entire' ? false : includeMinimap,
                            exportType,
                        });
                    }
                    catch (e) {
                        console.error(e);
                        setError(e);
                    }
                    onClose();
                } }, "Submit"),
            React.createElement(Button, { variant: "contained", color: "secondary", onClick: () => onClose() }, "Cancel"))));
}
//# sourceMappingURL=ExportSVGDialog.js.map