import React from 'react';
import { observer } from 'mobx-react';
import { Dialog } from '@jbrowse/core/ui';
import { Button, DialogContent } from '@mui/material';
import { getPalette } from '../../ggplotPalettes';
const Toggles = observer(function ({ model }) {
    const { featureFilters } = model;
    return (React.createElement("div", null,
        React.createElement(Button, { onClick: () => {
                for (const key of featureFilters.keys()) {
                    model.setFilter(key, true);
                }
            } }, "Toggle all on"),
        React.createElement(Button, { onClick: () => {
                for (const key of featureFilters.keys()) {
                    model.setFilter(key, false);
                }
            } }, "Toggle all off")));
});
const Table = observer(function ({ model }) {
    const { tidyTypes, featureFilters } = model;
    const values = [...tidyTypes.values()];
    const palette = getPalette(values.length - 1);
    return (React.createElement(React.Fragment, null,
        React.createElement(Toggles, { model: model }),
        React.createElement("table", null,
            React.createElement("thead", null,
                React.createElement("tr", null,
                    React.createElement("td", null),
                    React.createElement("td", null, "accession"),
                    React.createElement("td", null, "name"),
                    React.createElement("td", null, "description"))),
            React.createElement("tbody", null, values.map(({ accession, name, description }, idx) => (React.createElement("tr", { key: accession },
                React.createElement("td", null,
                    React.createElement("input", { type: "checkbox", checked: featureFilters.get(accession) ?? false, onChange: () => model.setFilter(accession, !model.featureFilters.get(accession)) })),
                React.createElement("td", null, accession),
                React.createElement("td", null, name),
                React.createElement("td", null, description),
                React.createElement("td", null,
                    React.createElement("div", { style: {
                            width: 20,
                            height: 20,
                            background: palette[idx] || 'black',
                        } })))))))));
});
const FeatureTypeDialog = observer(function ({ onClose, model, }) {
    return (React.createElement(Dialog, { onClose: () => onClose(), open: true, title: "Feature filters", maxWidth: "xl" },
        React.createElement(DialogContent, null,
            React.createElement(Table, { model: model }))));
});
export default FeatureTypeDialog;
//# sourceMappingURL=FeatureDialog.js.map