import React, { useState } from 'react';
import { observer } from 'mobx-react';
import { Dialog } from '@jbrowse/core/ui';
import { Button, DialogActions, DialogContent, Typography } from '@mui/material';
const FeatureTypeDialog = observer(function ({ onClose, model, }) {
    const [vals, setVals] = useState([
        {
            name: 'NCBIfam',
            description: 'NCBI RefSeq FAMs including TIGRFAMs',
            category: 'Families, domains, sites & repeats',
            checked: true,
        },
        {
            name: 'SFLD',
            description: 'Structure function linkage database',
            category: 'Families, domains, sites & repeats',
            checked: true,
        },
        {
            name: 'Phobius',
            checked: true,
            description: 'A combined transmembrane topology and signal peptide predictor',
            category: 'Other sequence features',
        },
        {
            name: 'SignalP',
            checked: true,
            category: 'Other sequence features',
        },
        {
            name: 'SignalP_EUK',
            category: 'Other category',
            checked: true,
        },
        {
            name: 'SignalP_GRAM_POSITIVE',
            category: 'Other category',
            checked: true,
        },
        {
            name: 'SignalP_GRAM_NEGATIVE',
            checked: true,
            category: 'Other category',
        },
        {
            name: 'SUPERFAMILY',
            category: 'Structural domains',
            checked: true,
        },
        {
            name: 'PANTHER',
            category: 'Families, domains, sites & repeats',
            checked: true,
        },
        {
            name: 'Gene3D',
            category: 'Structural domains',
            checked: true,
        },
        {
            name: 'Hamap',
            category: 'Families, domains, sites & repeats',
            checked: true,
        },
        {
            name: 'ProSiteProfiles',
            category: 'Families, domains, sites & repeats',
            checked: true,
        },
        {
            name: 'ProSitePatterns',
            category: 'Families, domains, sites & repeats',
            checked: true,
        },
        {
            name: 'Coils',
            category: 'Other sequence features',
            checked: true,
        },
        {
            name: 'SMART',
            category: 'Families, domains, sites & repeats',
            checked: true,
        },
        {
            name: 'CDD',
            description: 'Conserved Domains Database',
            category: 'Families, domains, sites & repeats',
            checked: true,
        },
        {
            name: 'PRINTS',
            category: 'Families, domains, sites & repeats',
            checked: true,
        },
        {
            name: 'Pfam',
            category: 'Families, domains, sites & repeats',
            checked: true,
        },
        {
            name: 'MobiDBLite',
            checked: true,
            category: 'Other sequence features',
        },
        {
            name: 'PIRSF',
            checked: true,
            category: 'Other category',
        },
        {
            name: 'TMHMM',
            checked: true,
            category: 'Other sequence features',
        },
        {
            name: 'AntiFam',
            checked: true,
            category: 'Other category',
        },
        {
            name: 'FunFam',
            checked: true,
            category: 'Other category',
        },
        {
            name: 'PIRSR',
            checked: true,
            category: 'Families, domains, sites & repeats',
        },
    ]);
    const programs = vals.filter(e => e.checked).map(e => e.name);
    const [show, setShow] = useState(false);
    return (React.createElement(Dialog, { onClose: () => onClose(), open: true, title: "Feature types", maxWidth: "xl" },
        React.createElement(DialogContent, null,
            React.createElement(Typography, null, "This will run InterProScan on all rows of the current MSA"),
            React.createElement(Button, { onClick: () => setShow(!show) },
                show ? 'Hide' : 'Show',
                " advanced options"),
            show ? (React.createElement("div", null,
                React.createElement(Typography, null, "Select algorithms for InterProScan to run"),
                React.createElement("div", null,
                    React.createElement(Button, { variant: "contained", color: "secondary", onClick: () => setVals(vals.map(v => ({ ...v, checked: false }))) }, "Select none"),
                    React.createElement(Button, { variant: "contained", color: "primary", onClick: () => setVals(vals.map(v => ({ ...v, checked: true }))) }, "Select all")),
                React.createElement("table", null,
                    React.createElement("tbody", null, vals
                        .sort((a, b) => a.category.localeCompare(b.category))
                        .map(({ name, checked, category }) => (React.createElement("tr", { key: name },
                        React.createElement("td", null,
                            React.createElement("input", { type: "checkbox", key: name, checked: checked, onChange: () => setVals(vals.map(e => e.name === name
                                    ? { ...e, checked: !e.checked }
                                    : e)) })),
                        React.createElement("td", null, name),
                        React.createElement("td", null, category)))))))) : null),
        React.createElement(DialogActions, null,
            React.createElement(Button, { variant: "contained", color: "secondary", onClick: () => onClose() }, "Cancel"),
            React.createElement(Button, { variant: "contained", color: "primary", onClick: () => {
                    model.queryInterProScan(programs).catch(e => model.setError(e));
                    onClose();
                } }, "Send sequences to InterProScan"))));
});
export default FeatureTypeDialog;
//# sourceMappingURL=InterProScanDialog.js.map