import React from 'react';
import { observer } from 'mobx-react';
import { makeStyles } from 'tss-react/mui';
import { Dialog } from '@jbrowse/core/ui';
import { Button, DialogActions, DialogContent, MenuItem, Slider, TextField, Typography, } from '@mui/material';
import colorSchemes from '../../colorSchemes';
import Checkbox2 from '../Checkbox2';
const useStyles = makeStyles()(theme => ({
    field: {
        margin: theme.spacing(4),
    },
    flex: {
        display: 'flex',
    },
}));
const SettingsContent = observer(function ({ model }) {
    return (React.createElement(React.Fragment, null,
        React.createElement(TreeSettings, { model: model }),
        React.createElement(MSASettings, { model: model })));
});
const TreeSettings = observer(function TreeSettings({ model, }) {
    const { classes } = useStyles();
    const { drawTree, drawLabels, drawNodeBubbles, labelsAlignRight, noTree, showBranchLen, treeWidthMatchesArea, treeWidth, } = model;
    return (React.createElement("div", null,
        React.createElement("h1", null, "Tree options"),
        React.createElement(Checkbox2, { checked: showBranchLen, onChange: () => model.setShowBranchLen(!showBranchLen), label: "Show branch length?" }),
        React.createElement(Checkbox2, { checked: drawNodeBubbles, onChange: () => model.setDrawNodeBubbles(!drawNodeBubbles), label: "Draw clickable bubbles on tree branches?" }),
        React.createElement(Checkbox2, { checked: drawTree, onChange: () => model.setDrawTree(!drawTree), label: "Show tree?" }),
        React.createElement(Checkbox2, { checked: labelsAlignRight, onChange: () => model.setLabelsAlignRight(!labelsAlignRight), label: "Tree labels align right?" }),
        React.createElement(Checkbox2, { checked: drawLabels, onChange: () => model.setDrawLabels(!drawLabels), label: "Draw labels" }),
        !noTree ? (React.createElement("div", null,
            React.createElement(Checkbox2, { checked: treeWidthMatchesArea, onChange: () => model.setTreeWidthMatchesArea(!treeWidthMatchesArea), label: "Make tree width fit to tree area?" }),
            !treeWidthMatchesArea ? (React.createElement("div", { className: classes.flex },
                React.createElement(Typography, null,
                    "Tree width (",
                    treeWidth,
                    "px)"),
                React.createElement(Slider, { className: classes.field, min: 50, max: 600, value: treeWidth, onChange: (_, val) => model.setTreeWidth(val) }))) : null)) : null));
});
const MSASettings = observer(function MSASettings({ model, }) {
    const { classes } = useStyles();
    const { bgColor, colWidth, colorSchemeName, rowHeight } = model;
    return (React.createElement("div", null,
        React.createElement("h1", null, "MSA options"),
        React.createElement(Checkbox2, { checked: bgColor, onChange: () => model.setBgColor(!bgColor), label: "Color background tiles of MSA?" }),
        React.createElement("div", { className: classes.flex },
            React.createElement(Typography, null,
                "Column width (",
                colWidth,
                "px)"),
            React.createElement(Slider, { className: classes.field, min: 1, max: 50, value: colWidth, onChange: (_, val) => model.setColWidth(val) })),
        React.createElement("div", { className: classes.flex },
            React.createElement(Typography, null,
                "Row height (",
                rowHeight,
                "px)"),
            React.createElement(Slider, { className: classes.field, min: 1, max: 50, value: rowHeight, onChange: (_, val) => model.setRowHeight(val) })),
        React.createElement(TextField, { select: true, label: "Color scheme", value: colorSchemeName, onChange: event => model.setColorSchemeName(event.target.value) }, Object.keys(colorSchemes).map(option => (React.createElement(MenuItem, { key: option, value: option }, option))))));
});
const SettingsDialog = observer(function ({ model, onClose, }) {
    return (React.createElement(Dialog, { open: true, onClose: () => onClose(), title: "Settings", maxWidth: "xl" },
        React.createElement(DialogContent, { style: { width: '80em' } },
            React.createElement(SettingsContent, { model: model }),
            React.createElement(DialogActions, null,
                React.createElement(Button, { onClick: () => onClose(), variant: "contained", color: "primary" }, "Submit")))));
});
export default SettingsDialog;
//# sourceMappingURL=SettingsDialog.js.map