export function renderBoxFeatureCanvasBlock({ model, offsetX, offsetY, ctx, highResScaleFactorOverride, blockSizeYOverride, }) {
    const { hierarchy, blockSize, rowHeight, highResScaleFactor, featureMode } = model;
    if (featureMode) {
        const k = highResScaleFactorOverride || highResScaleFactor;
        const by = blockSizeYOverride || blockSize;
        ctx.resetTransform();
        ctx.scale(k, k);
        ctx.translate(-offsetX, rowHeight / 2 - offsetY);
        const leaves = hierarchy.leaves();
        const yStart = Math.max(0, Math.floor((offsetY - rowHeight) / rowHeight));
        const yEnd = Math.max(0, Math.ceil((offsetY + by + rowHeight) / rowHeight));
        const visibleLeaves = leaves.slice(yStart, yEnd);
        drawTiles({
            model,
            ctx,
            visibleLeaves,
        });
    }
}
function drawTiles({ model, ctx, visibleLeaves, }) {
    const { subFeatureRows, colWidth, rowHeight, fillPalette, strokePalette, tidyFilteredGatheredAnnotations, } = model;
    for (const node of visibleLeaves) {
        const { x, data: { name }, } = node;
        const y = x;
        const entry = tidyFilteredGatheredAnnotations?.[name];
        let j = 0;
        if (entry) {
            for (const { start, end, accession } of entry) {
                const m1 = model.seqCoordToRowSpecificGlobalCoord(name, start - 1);
                const m2 = model.seqCoordToRowSpecificGlobalCoord(name, end);
                const x = m1 * colWidth;
                ctx.fillStyle = fillPalette[accession];
                ctx.strokeStyle = strokePalette[accession];
                const h = subFeatureRows ? 4 : rowHeight;
                const t = y - rowHeight + (subFeatureRows ? j * h : 0);
                const lw = colWidth * (m2 - m1);
                ctx.fillRect(x, t, lw, h);
                ctx.strokeRect(x, t, lw, h);
                j++;
            }
        }
    }
}
//# sourceMappingURL=renderBoxFeatureCanvasBlock.js.map