import React from 'react';
import { Instance } from 'mobx-state-tree';
import { HierarchyNode } from 'd3-hierarchy';
import { Theme } from '@mui/material';
import { FileLocation as FileLocationType } from '@jbrowse/core/util/types';
import { NodeWithIds, NodeWithIdsAndLength } from './util';
import ClustalMSA from './parsers/ClustalMSA';
import StockholmMSA from './parsers/StockholmMSA';
import FastaMSA from './parsers/FastaMSA';
import { InterProScanResults } from './launchInterProScan';
export interface Accession {
    accession: string;
    name: string;
    description: string;
}
export interface BasicTrackModel {
    id: string;
    name: string;
    associatedRowName?: string;
    height: number;
}
export interface TextTrackModel extends BasicTrackModel {
    customColorScheme?: Record<string, string>;
    data: string;
}
export interface ITextTrack {
    ReactComponent: React.FC<any>;
    model: TextTrackModel;
}
export type BasicTrack = ITextTrack;
/**
 * #stateModel MsaView
 * extends
 * - DialogQueueSessionMixin
 * - MSAModel
 * - Tree
 */
declare function stateModelFactory(): import("mobx-state-tree").IModelType<{
    drawLabels: import("mobx-state-tree").IType<boolean | undefined, boolean, boolean>;
    labelsAlignRight: import("mobx-state-tree").IType<boolean | undefined, boolean, boolean>;
    treeAreaWidth: import("mobx-state-tree").IOptionalIType<import("mobx-state-tree").ISimpleType<number>, [undefined]>;
    treeWidth: import("mobx-state-tree").IOptionalIType<import("mobx-state-tree").ISimpleType<number>, [undefined]>;
    treeWidthMatchesArea: import("mobx-state-tree").IType<boolean | undefined, boolean, boolean>;
    showBranchLen: import("mobx-state-tree").IType<boolean | undefined, boolean, boolean>;
    drawTree: import("mobx-state-tree").IType<boolean | undefined, boolean, boolean>;
    drawNodeBubbles: import("mobx-state-tree").IType<boolean | undefined, boolean, boolean>;
} & {
    bgColor: import("mobx-state-tree").IType<boolean | undefined, boolean, boolean>;
    colorSchemeName: import("mobx-state-tree").IType<string | undefined, string, string>;
} & {
    id: import("mobx-state-tree").IOptionalIType<import("mobx-state-tree").ISimpleType<string>, [undefined]>;
    featureMode: import("mobx-state-tree").IType<boolean | undefined, boolean, boolean>;
    subFeatureRows: import("mobx-state-tree").IType<boolean | undefined, boolean, boolean>;
    type: import("mobx-state-tree").ISimpleType<"MsaView">;
    height: import("mobx-state-tree").IOptionalIType<import("mobx-state-tree").ISimpleType<number>, [undefined]>;
    rowHeight: import("mobx-state-tree").IType<number | undefined, number, number>;
    scrollY: import("mobx-state-tree").IType<number | undefined, number, number>;
    scrollX: import("mobx-state-tree").IType<number | undefined, number, number>;
    colWidth: import("mobx-state-tree").IType<number | undefined, number, number>;
    treeFilehandle: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISnapshotProcessor<import("mobx-state-tree").ITypeUnion<import("mobx-state-tree").ModelCreationType<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"UriLocation">;
        uri: import("mobx-state-tree").ISimpleType<string>;
        baseUri: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountId: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountPreAuthorization: import("mobx-state-tree").IMaybe<import("mobx-state-tree").IModelType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>;
        }, {}, import("mobx-state-tree")._NotCustomized, import("mobx-state-tree")._NotCustomized>>;
    }>> | import("mobx-state-tree").ModelCreationType<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }>> | import("mobx-state-tree").ModelCreationType<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }>>, {
        locationType: "UriLocation";
        uri: string;
        internetAccountId: string | undefined;
        internetAccountPreAuthorization: import("mobx-state-tree").ModelSnapshotType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>;
        }> | undefined;
    } | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }> | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }>, import("mobx-state-tree").ModelInstanceType<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }, {}> | import("mobx-state-tree").ModelInstanceType<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }, {}> | ({
        locationType: "UriLocation";
        uri: string;
    } & Partial<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"UriLocation">;
        uri: import("mobx-state-tree").ISimpleType<string>;
        baseUri: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountId: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountPreAuthorization: import("mobx-state-tree").IMaybe<import("mobx-state-tree").IModelType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>; /**
             * #action
             */
        }, {}, import("mobx-state-tree")._NotCustomized, import("mobx-state-tree")._NotCustomized>>;
    }>> & import("mobx-state-tree/dist/internal").NonEmptyObject)>, import("mobx-state-tree")._NotCustomized, import("mobx-state-tree")._NotCustomized>>;
    msaFilehandle: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISnapshotProcessor<import("mobx-state-tree").ITypeUnion<import("mobx-state-tree").ModelCreationType<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"UriLocation">;
        uri: import("mobx-state-tree").ISimpleType<string>;
        baseUri: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountId: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountPreAuthorization: import("mobx-state-tree").IMaybe<import("mobx-state-tree").IModelType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>;
        }, {}, import("mobx-state-tree")._NotCustomized, import("mobx-state-tree")._NotCustomized>>;
    }>> | import("mobx-state-tree").ModelCreationType<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }>> | import("mobx-state-tree").ModelCreationType<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }>>, {
        locationType: "UriLocation";
        uri: string;
        internetAccountId: string | undefined;
        internetAccountPreAuthorization: import("mobx-state-tree").ModelSnapshotType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>;
        }> | undefined;
    } | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }> | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }>, import("mobx-state-tree").ModelInstanceType<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }, {}> | import("mobx-state-tree").ModelInstanceType<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }, {}> | ({
        locationType: "UriLocation";
        uri: string;
    } & Partial<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"UriLocation">;
        uri: import("mobx-state-tree").ISimpleType<string>;
        baseUri: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountId: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountPreAuthorization: import("mobx-state-tree").IMaybe<import("mobx-state-tree").IModelType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>; /**
             * #action
             */
        }, {}, import("mobx-state-tree")._NotCustomized, import("mobx-state-tree")._NotCustomized>>;
    }>> & import("mobx-state-tree/dist/internal").NonEmptyObject)>, import("mobx-state-tree")._NotCustomized, import("mobx-state-tree")._NotCustomized>>;
    treeMetadataFilehandle: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISnapshotProcessor<import("mobx-state-tree").ITypeUnion<import("mobx-state-tree").ModelCreationType<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"UriLocation">;
        uri: import("mobx-state-tree").ISimpleType<string>;
        baseUri: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountId: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountPreAuthorization: import("mobx-state-tree").IMaybe<import("mobx-state-tree").IModelType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>;
        }, {}, import("mobx-state-tree")._NotCustomized, import("mobx-state-tree")._NotCustomized>>;
    }>> | import("mobx-state-tree").ModelCreationType<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }>> | import("mobx-state-tree").ModelCreationType<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }>>, {
        locationType: "UriLocation";
        uri: string;
        internetAccountId: string | undefined;
        internetAccountPreAuthorization: import("mobx-state-tree").ModelSnapshotType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>;
        }> | undefined;
    } | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }> | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }>, import("mobx-state-tree").ModelInstanceType<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }, {}> | import("mobx-state-tree").ModelInstanceType<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }, {}> | ({
        locationType: "UriLocation";
        uri: string;
    } & Partial<import("mobx-state-tree/dist/internal").ExtractCFromProps<{
        locationType: import("mobx-state-tree").ISimpleType<"UriLocation">;
        uri: import("mobx-state-tree").ISimpleType<string>;
        baseUri: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountId: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        internetAccountPreAuthorization: import("mobx-state-tree").IMaybe<import("mobx-state-tree").IModelType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>; /**
             * #action
             */
        }, {}, import("mobx-state-tree")._NotCustomized, import("mobx-state-tree")._NotCustomized>>;
    }>> & import("mobx-state-tree/dist/internal").NonEmptyObject)>, import("mobx-state-tree")._NotCustomized, import("mobx-state-tree")._NotCustomized>>;
    currentAlignment: import("mobx-state-tree").IType<number | undefined, number, number>;
    collapsed: import("mobx-state-tree").IArrayType<import("mobx-state-tree").ISimpleType<string>>;
    collapsed2: import("mobx-state-tree").IArrayType<import("mobx-state-tree").ISimpleType<string>>;
    showOnly: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
    turnedOffTracks: import("mobx-state-tree").IMapType<import("mobx-state-tree").ISimpleType<boolean>>;
    data: import("mobx-state-tree").IOptionalIType<import("mobx-state-tree").IModelType<{
        tree: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        msa: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
        treeMetadata: import("mobx-state-tree").IMaybe<import("mobx-state-tree").ISimpleType<string>>;
    }, {
        setTree(tree?: string | undefined): void;
        setMSA(msa?: string | undefined): void;
        setTreeMetadata(treeMetadata?: string | undefined): void;
    }, import("mobx-state-tree")._NotCustomized, import("mobx-state-tree")._NotCustomized>, [undefined]>;
    featureFilters: import("mobx-state-tree").IMapType<import("mobx-state-tree").ISimpleType<boolean>>;
}, {
    queueOfDialogs: [import("@jbrowse/core/util").DialogComponentType, any][];
} & {
    readonly DialogComponent: import("@jbrowse/core/util").DialogComponentType;
    readonly DialogProps: any;
} & {
    removeActiveDialog(): void;
    queueDialog(cb: (doneCallback: () => void) => [import("@jbrowse/core/util").DialogComponentType, unknown]): void;
} & {
    setTreeWidthMatchesArea(arg: boolean): void;
    setTreeAreaWidth(n: number): void;
    setTreeWidth(n: number): void;
    setLabelsAlignRight(arg: boolean): void;
    setDrawTree(arg: boolean): void;
    setShowBranchLen(arg: boolean): void;
    setDrawNodeBubbles(arg: boolean): void;
    setDrawLabels(arg: boolean): void;
} & {
    setColorSchemeName(name: string): void;
    setBgColor(arg: boolean): void;
} & {
    status: {
        msg: string;
        url?: string | undefined;
    } | undefined;
    /**
     * #volatile
     * high resolution scale factor, helps make canvas look better on hi-dpi
     * screens
     */
    highResScaleFactor: number;
    /**
     * #volatile
     */
    loadingMSA: boolean;
    /**
     * #volatile
     */
    loadingTree: boolean;
    /**
     * #volatile
     */
    width: number;
    /**
     * #volatile
     * resize handle width between tree and msa area, px
     */
    resizeHandleWidth: number;
    /**
     * #volatile
     * size of blocks of content to be drawn, px
     */
    blockSize: number;
    /**
     * #volatile
     * the currently mouse-hovered row
     */
    mouseRow: number | undefined;
    /**
     * #volatile
     * the currently mouse-hovered column
     */
    mouseCol: number | undefined;
    /**
     * #volatile
     * the currently mouse-click row
     */
    mouseClickRow: number | undefined;
    /**
     * #volatile
     * the currently mouse-click column
     */
    mouseClickCol: number | undefined;
    /**
     * #volatile
     * a dummy variable that is incremented when ref changes so autorun for
     * drawing canvas commands will run
     */
    nref: number;
    /**
     * #volatile
     */
    minimapHeight: number;
    /**
     * #volatile
     */
    marginLeft: number;
    /**
     * #volatile
     */
    error: unknown;
    /**
     * #volatile
     */
    annotPos: {
        left: number;
        right: number;
    } | undefined;
    /**
     * #volatile
     *
     */
    loadedInterProAnnotations: Record<string, InterProScanResults> | undefined;
    /**
     * #volatile
     */
    interProScanJobIds: {
        jobId: string;
        date: number;
    }[];
} & {
    /**
     * #action
     */
    setLoadingMSA(arg: boolean): void;
    /**
     * #action
     */
    setLoadingTree(arg: boolean): void;
    /**
     * #action
     */
    setWidth(arg: number): void;
    /**
     * #action
     * set the height of the view in px
     */
    setHeight(height: number): void;
    /**
     * #action
     * set error state
     */
    setError(error?: unknown): void;
    /**
     * #action
     * set mouse position (row, column) in the MSA
     */
    setMousePos(col?: number, row?: number): void;
    /**
     * #action
     */
    setFeatureMode(arg: boolean): void;
    /**
     * #action
     */
    setSubFeatureRows(arg: boolean): void;
    /**
     * #action
     * set mouse click position (row, column) in the MSA
     */
    setMouseClickPos(col?: number, row?: number): void;
    /**
     * #action
     * set row height (px)
     */
    setRowHeight(n: number): void;
    /**
     * #action
     * set col width (px)
     */
    setColWidth(n: number): void;
    /**
     * #action
     * set scroll Y-offset (px)
     */
    setScrollY(n: number): void;
    /**
     * #action
     *
     */
    setCurrentAlignment(n: number): void;
    /**
     * #action
     */
    toggleCollapsed(node: string): void;
    /**
     * #action
     */
    toggleCollapsed2(node: string): void;
    /**
     * #action
     */
    setShowOnly(node?: string): void;
    /**
     * #action
     */
    setData(data: {
        msa?: string;
        tree?: string;
    }): void;
    /**
     * #action
     */
    setMSAFilehandle(msaFilehandle?: FileLocationType): void;
    /**
     * #action
     */
    setTreeFilehandle(treeFilehandle?: FileLocationType): void;
    /**
     * #action
     */
    setMSA(result: string): void;
    /**
     * #action
     */
    setTree(result: string): void;
    /**
     * #action
     */
    setTreeMetadata(result: string): void;
} & {
    /**
     * #method
     * unused here, but can be used by derived classes to add extra items
     */
    extraViewMenuItems(): never[];
    /**
     * #getter
     */
    readonly colorScheme: Record<string, string>;
    /**
     * #getter
     */
    readonly header: {};
    /**
     * #method
     */
    getRowData(name: string): {
        data: {
            name: string;
            accession: string;
            dbxref: string;
        } | undefined;
    };
    /**
     * #getter
     */
    readonly alignmentNames: string[];
    /**
     * #getter
     */
    readonly noTree: boolean;
    /**
     * #getter
     */
    readonly noAnnotations: boolean;
    /**
     * #getter
     */
    readonly menuItems: never[];
    /**
     * #getter
     */
    readonly treeMetadata: any;
    /**
     * #getter
     */
    readonly MSA: StockholmMSA | FastaMSA | ClustalMSA | null;
    /**
     * #getter
     */
    readonly numColumns: number;
    /**
     * #getter
     */
    readonly _tree: NodeWithIds;
    /**
     * #getter
     */
    readonly rowNames: string[];
    /**
     * #getter
     */
    readonly mouseOverRowName: string | undefined;
    /**
     * #getter
     */
    readonly root: HierarchyNode<NodeWithIds>;
    /**
     * #getter
     * widget width minus the tree area gives the space for the MSA
     */
    readonly msaAreaWidth: number;
    /**
     * #getter
     */
    readonly treeAreaWidthMinusMargin: number;
    /**
     * #getter
     */
    readonly blanks: number[];
    /**
     * #getter
     */
    readonly rows: [string, string][];
    /**
     * #getter
     */
    readonly columns: {
        [k: string]: string;
    };
    /**
     * #getter
     */
    readonly columns2d: string[];
    /**
     * #getter
     */
    readonly fontSize: number;
    /**
     * #getter
     */
    readonly colStats: Record<string, number>[];
    /**
     * #getter
     * generates a new tree that is clustered with x,y positions
     */
    readonly hierarchy: HierarchyNode<NodeWithIdsAndLength>;
    /**
     * #getter
     */
    readonly totalHeight: number;
} & {
    /**
     * #getter
     */
    readonly totalWidth: number;
} & {
    /**
     * #getter
     */
    readonly initialized: boolean | "" | undefined;
    /**
     * #getter
     */
    readonly blocksX: number[];
    /**
     * #getter
     */
    readonly blocksY: number[];
} & {
    /**
     * #getter
     */
    readonly blocks2d: number[][];
    /**
     * #getter
     */
    readonly isLoading: boolean;
    /**
     * #getter
     */
    readonly maxScrollX: number;
} & {
    /**
     * #action
     */
    zoomIn(): void;
    /**
     * #action
     */
    zoomOut(): void;
    /**
     * #action
     */
    setLoadedInterProAnnotations(data: Record<string, InterProScanResults>): void;
    /**
     * #action
     */
    doScrollY(deltaY: number): void;
    /**
     * #action
     */
    doScrollX(deltaX: number): void;
    /**
     * #action
     */
    setScrollX(n: number): void;
    /**
     * #action
     */
    toggleTrack(id: string): void;
    /**
     * #action
     */
    addInterProScanJobId(arg: string): void;
    /**
     * #action
     */
    setStatus(status?: {
        msg: string;
        url?: string;
    }): void;
} & {
    /**
     * #getter
     */
    readonly labelsWidth: number;
    /**
     * #getter
     */
    readonly secondaryStructureConsensus: string | undefined;
    /**
     * #getter
     */
    readonly seqConsensus: string | undefined;
    /**
     * #getter
     */
    readonly conservation: string[];
    /**
     * #getter
     */
    readonly adapterTrackModels: ITextTrack[];
    /**
     * #getter
     */
    readonly tracks: ITextTrack[];
    /**
     * #getter
     */
    readonly turnedOnTracks: ITextTrack[];
    /**
     * #method
     * return a row-specific sequence coordinate, skipping gaps, given a global
     * coordinate
     */
    globalCoordToRowSpecificSeqCoord(rowName: string, position: number): number;
    /**
     * #method
     * return a global coordinate given a row-specific sequence coordinate
     * which does not not include gaps
     */
    seqCoordToRowSpecificGlobalCoord(rowName: string, position: number): number;
} & {
    /**
     * #getter
     * total height of track area (px)
     */
    readonly totalTrackAreaHeight: number;
    /**
     * #getter
     */
    readonly tidyTypes: Map<string, Accession>;
    readonly tidyAnnotations: {
        id: string;
        name: string;
        accession: string;
        description: string;
        start: number;
        end: number;
    }[];
    /**
     * #getter
     */
    readonly tidyFilteredAnnotations: {
        id: string;
        name: string;
        accession: string;
        description: string;
        start: number;
        end: number;
    }[];
    /**
     * #getter
     */
    readonly tidyFilteredGatheredAnnotations: Record<string, {
        id: string;
        name: string;
        accession: string;
        description: string;
        start: number;
        end: number;
    }[] | undefined>;
} & {
    readonly fillPalette: Record<string, string>;
    readonly strokePalette: {
        [k: string]: string;
    };
} & {
    /**
     * #action
     */
    loadInterProScanResults(jobId: string): Promise<void>;
    /**
     * #action
     */
    queryInterProScan(programs: string[]): Promise<void>;
    /**
     * #action
     */
    reset(): void;
    /**
     * #action
     */
    exportSVG(opts: {
        theme: Theme;
        includeMinimap?: boolean;
        exportType: string;
    }): Promise<void>;
    /**
     * #action
     * internal, used for drawing to canvas
     */
    incrementRef(): void;
    /**
     * #action
     */
    initFilter(arg: string): void;
    /**
     * #action
     */
    setFilter(arg: string, flag: boolean): void;
    afterCreate(): void;
}, import("mobx-state-tree")._NotCustomized, {
    height: number;
    drawLabels: boolean;
    labelsAlignRight: boolean;
    treeAreaWidth: number;
    treeWidth: number;
    treeWidthMatchesArea: boolean;
    showBranchLen: boolean;
    drawTree: boolean;
    drawNodeBubbles: boolean;
    bgColor: boolean;
    colorSchemeName: string;
    id: string;
    featureMode: boolean;
    subFeatureRows: boolean;
    rowHeight: number;
    scrollY: number;
    scrollX: number;
    colWidth: number;
    currentAlignment: number;
    type: "MsaView";
    treeFilehandle: {
        locationType: "UriLocation";
        uri: string;
        internetAccountId: string | undefined;
        internetAccountPreAuthorization: import("mobx-state-tree").ModelSnapshotType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>;
        }> | undefined;
    } | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }> | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }> | undefined;
    msaFilehandle: {
        locationType: "UriLocation";
        uri: string;
        internetAccountId: string | undefined;
        internetAccountPreAuthorization: import("mobx-state-tree").ModelSnapshotType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>;
        }> | undefined;
    } | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }> | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }> | undefined;
    treeMetadataFilehandle: {
        locationType: "UriLocation";
        uri: string;
        internetAccountId: string | undefined;
        internetAccountPreAuthorization: import("mobx-state-tree").ModelSnapshotType<{
            internetAccountType: import("mobx-state-tree").ISimpleType<string>;
            authInfo: import("mobx-state-tree").IType<any, any, any>;
        }> | undefined;
    } | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"BlobLocation">;
        name: import("mobx-state-tree").ISimpleType<string>;
        blobId: import("mobx-state-tree").ISimpleType<string>;
    }> | import("mobx-state-tree").ModelSnapshotType<{
        locationType: import("mobx-state-tree").ISimpleType<"LocalPathLocation">;
        localPath: import("mobx-state-tree").ISimpleType<string>;
    }> | undefined;
    collapsed: string[];
    collapsed2: string[];
    showOnly: string | undefined;
    turnedOffTracks: import("mobx").IKeyValueMap<boolean>;
    featureFilters: import("mobx").IKeyValueMap<boolean>;
    data: {
        treeMetadata?: string | undefined;
        msa?: string | undefined;
        tree?: string | undefined;
    };
}>;
export default stateModelFactory;
export type MsaViewStateModel = ReturnType<typeof stateModelFactory>;
export type MsaViewModel = Instance<MsaViewStateModel>;
