import { NodeWithIds } from '../util';
interface StockholmEntry {
    gf: {
        DE?: string[];
        NH?: string[];
    };
    gs: {
        AC: Record<string, string>;
        DR: Record<string, string>;
    };
    gc?: {
        SS_cons?: string;
        seq_cons?: string;
    };
    seqdata: Record<string, string>;
}
export default class StockholmMSA {
    private data;
    private MSA;
    constructor(text: string, currentAlignment: number);
    getMSA(): StockholmEntry;
    getRow(name: string): string;
    getWidth(): number;
    get alignmentNames(): string[];
    getHeader(): {
        General: {
            DE?: string[] | undefined;
            NH?: string[] | undefined;
        };
        Accessions: Record<string, string>;
        Dbxref: Record<string, string>;
    };
    getRowData(rowName: string): {
        name: string;
        accession: string;
        dbxref: string;
    };
    getNames(): string[];
    getSeqCoords(): void;
    getStructures(): Record<string, Omit<{
        id: string;
        pdb: string;
        chain: string;
        startPos: number;
        endPos: number;
    }, "id">[]>;
    getTree(): NodeWithIds;
    get seqConsensus(): string | undefined;
    get secondaryStructureConsensus(): string | undefined;
    get tracks(): ({
        id: string;
        name: string;
        data: string | undefined;
        customColorScheme: {
            '>'?: undefined;
            '<'?: undefined;
        };
    } | {
        id: string;
        name: string;
        data: string | undefined;
        customColorScheme: {
            '>': string;
            '<': string;
        };
    })[];
}
export {};
