import { max } from 'd3-array';
import { colord, extend } from 'colord';
import namesPlugin from 'colord/plugins/names';
extend([namesPlugin]);
export function transform(obj, cb) {
    return Object.fromEntries(Object.entries(obj).map(cb));
}
export function generateNodeIds(tree, parent = 'node', depth = 0) {
    const id = `${parent}-${depth}`;
    return {
        ...tree,
        id,
        name: tree.name || id,
        branchset: tree.branchset?.map((b, i) => generateNodeIds(b, `${id}-${i}`, depth + 1)) || [],
    };
}
export function colorContrast(colorScheme, theme) {
    return transform(colorScheme, ([letter, color]) => [
        letter,
        theme.palette.getContrastText(colord(color).toHex()),
    ]);
}
export function skipBlanks(blanks, arg) {
    let s = '';
    let b = 0;
    for (let j = 0; j < arg.length; j++) {
        if (j === blanks[b]) {
            b++;
        }
        else {
            s += arg[j];
        }
    }
    return s;
}
// basically same as setRadius from https://observablehq.com/@d3/tree-of-life
export function setBrLength(d, y0, k) {
    // @ts-expect-error
    d.len = (y0 += Math.max(d.data.length || 0, 0)) * k;
    if (d.children) {
        d.children.forEach(d => {
            setBrLength(d, y0, k);
        });
    }
}
// basically same as maxLength from https://observablehq.com/@d3/tree-of-life
export function maxLength(d) {
    return ((d.data.length || 0) + (d.children ? max(d.children, maxLength) || 0 : 0));
}
// Collapse the node and all it's children, from
// https://bl.ocks.org/d3noob/43a860bc0024792f8803bba8ca0d5ecd
export function collapse(d) {
    if (d.children) {
        // @ts-expect-error
        d._children = d.children;
        // @ts-expect-error
        d._children.forEach(collapse);
        // @ts-expect-error
        d.children = null;
    }
}
export function clamp(min, num, max) {
    return Math.min(Math.max(num, min), max);
}
export function len(a) {
    return a.end - a.start;
}
//# sourceMappingURL=util.js.map